==> cscec5b-xell-api-3.0.1-20221201.124507-44-sources.jar: com/ejianc/business/wzxt/vo/CauseDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 节超原因子表
 * 
 * @author generator
 * 
 */
public class CauseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long causeId; // 主表id
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String constructionDetail; // 部位名称
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private BigDecimal designNums; // 设计用量
    private BigDecimal planNums; // 计划用量
    private BigDecimal realityNums; // 实际用量
    private BigDecimal quotaNums; // 定额用量
    private BigDecimal dutySaveRate; // 目标节约率
    private BigDecimal dutyNums; // 目标用量
    private BigDecimal exceedRate; // 节超率
    private Long dutyPersonDetailId; // 责任人ID
    private String dutyPersonDetailName; // 责任人
    private String dutySectionDetail; // 责任工区
    private String exceedCauseDetail; // 节超原因分析
    private String improvementMeasureDetail; // 改进措施

    public Long getCauseId() {
        return causeId;
    }

    public void setCauseId(Long causeId) {
        this.causeId = causeId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionDetail() {
        return constructionDetail;
    }

    public void setConstructionDetail(String constructionDetail) {
        this.constructionDetail = constructionDetail;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDesignNums() {
        return designNums;
    }

    public void setDesignNums(BigDecimal designNums) {
        this.designNums = designNums;
    }
    public BigDecimal getPlanNums() {
        return planNums;
    }

    public void setPlanNums(BigDecimal planNums) {
        this.planNums = planNums;
    }
    public BigDecimal getRealityNums() {
        return realityNums;
    }

    public void setRealityNums(BigDecimal realityNums) {
        this.realityNums = realityNums;
    }
    public BigDecimal getQuotaNums() {
        return quotaNums;
    }

    public void setQuotaNums(BigDecimal quotaNums) {
        this.quotaNums = quotaNums;
    }
    public BigDecimal getDutySaveRate() {
        return dutySaveRate;
    }

    public void setDutySaveRate(BigDecimal dutySaveRate) {
        this.dutySaveRate = dutySaveRate;
    }
    public BigDecimal getDutyNums() {
        return dutyNums;
    }

    public void setDutyNums(BigDecimal dutyNums) {
        this.dutyNums = dutyNums;
    }
    public BigDecimal getExceedRate() {
        return exceedRate;
    }

    public void setExceedRate(BigDecimal exceedRate) {
        this.exceedRate = exceedRate;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getDutyPersonDetailId() {
        return dutyPersonDetailId;
    }

    @ReferDeserialTransfer
    public void setDutyPersonDetailId(Long dutyPersonDetailId) {
        this.dutyPersonDetailId = dutyPersonDetailId;
    }
    public String getDutyPersonDetailName() {
        return dutyPersonDetailName;
    }

    public void setDutyPersonDetailName(String dutyPersonDetailName) {
        this.dutyPersonDetailName = dutyPersonDetailName;
    }
    public String getDutySectionDetail() {
        return dutySectionDetail;
    }

    public void setDutySectionDetail(String dutySectionDetail) {
        this.dutySectionDetail = dutySectionDetail;
    }
    public String getExceedCauseDetail() {
        return exceedCauseDetail;
    }

    public void setExceedCauseDetail(String exceedCauseDetail) {
        this.exceedCauseDetail = exceedCauseDetail;
    }
    public String getImprovementMeasureDetail() {
        return improvementMeasureDetail;
    }

    public void setImprovementMeasureDetail(String improvementMeasureDetail) {
        this.improvementMeasureDetail = improvementMeasureDetail;
    }
    
}

==> cscec5b-xell-api-3.0.1-20240824.044821-79-sources.jar: com/ejianc/business/wzxt/vo/CauseDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 节超原因子表
 *
 * @author generator
 *
 */
public class CauseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long causeId; // 主表id
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String parentOrgName; // 所属单位
    private Long wbsId; // wbsId
    private String constructionDetail; // 部位名称
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private BigDecimal designNums; // 设计用量
    private BigDecimal planNums; // 计划用量
    private BigDecimal realityNums; // 实际用量
    private BigDecimal quotaNums; // 定额用量
    private BigDecimal dutySaveRate; // 目标节约率
    private BigDecimal dutyNums; // 目标用量
    private BigDecimal exceedRate; // 节超率
    private Long dutyPersonDetailId; // 责任人ID
    private String dutyPersonDetailName; // 责任人
    private String dutySectionDetail; // 责任工区
    private String exceedCauseDetail; // 节超原因分析
    private String improvementMeasureDetail; // 改进措施

    private String planEmployeeName;
    private String planTime;
    private String checkTime;

    public Long getCauseId() {
        return causeId;
    }

    public void setCauseId(Long causeId) {
        this.causeId = causeId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getConstructionDetail() {
        return constructionDetail;
    }

    public void setConstructionDetail(String constructionDetail) {
        this.constructionDetail = constructionDetail;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDesignNums() {
        return designNums;
    }

    public void setDesignNums(BigDecimal designNums) {
        this.designNums = designNums;
    }
    public BigDecimal getPlanNums() {
        return planNums;
    }

    public void setPlanNums(BigDecimal planNums) {
        this.planNums = planNums;
    }
    public BigDecimal getRealityNums() {
        return realityNums;
    }

    public void setRealityNums(BigDecimal realityNums) {
        this.realityNums = realityNums;
    }
    public BigDecimal getQuotaNums() {
        return quotaNums;
    }

    public void setQuotaNums(BigDecimal quotaNums) {
        this.quotaNums = quotaNums;
    }
    public BigDecimal getDutySaveRate() {
        return dutySaveRate;
    }

    public void setDutySaveRate(BigDecimal dutySaveRate) {
        this.dutySaveRate = dutySaveRate;
    }
    public BigDecimal getDutyNums() {
        return dutyNums;
    }

    public void setDutyNums(BigDecimal dutyNums) {
        this.dutyNums = dutyNums;
    }
    public BigDecimal getExceedRate() {
        return exceedRate;
    }

    public void setExceedRate(BigDecimal exceedRate) {
        this.exceedRate = exceedRate;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getDutyPersonDetailId() {
        return dutyPersonDetailId;
    }

    @ReferDeserialTransfer
    public void setDutyPersonDetailId(Long dutyPersonDetailId) {
        this.dutyPersonDetailId = dutyPersonDetailId;
    }
    public String getDutyPersonDetailName() {
        return dutyPersonDetailName;
    }

    public void setDutyPersonDetailName(String dutyPersonDetailName) {
        this.dutyPersonDetailName = dutyPersonDetailName;
    }
    public String getDutySectionDetail() {
        return dutySectionDetail;
    }

    public void setDutySectionDetail(String dutySectionDetail) {
        this.dutySectionDetail = dutySectionDetail;
    }
    public String getExceedCauseDetail() {
        return exceedCauseDetail;
    }

    public void setExceedCauseDetail(String exceedCauseDetail) {
        this.exceedCauseDetail = exceedCauseDetail;
    }
    public String getImprovementMeasureDetail() {
        return improvementMeasureDetail;
    }

    public void setImprovementMeasureDetail(String improvementMeasureDetail) {
        this.improvementMeasureDetail = improvementMeasureDetail;
    }

    public String getPlanEmployeeName() {
        return planEmployeeName;
    }

    public void setPlanEmployeeName(String planEmployeeName) {
        this.planEmployeeName = planEmployeeName;
    }

    public String getPlanTime() {
        return planTime;
    }

    public void setPlanTime(String planTime) {
        this.planTime = planTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
}
